From 83131acbfb59760a19f3711c09526e191c8aad54 Mon Sep 17 00:00:00 2001
From: Jonas Gorski <jogo@openwrt.org>
Date: Tue, 29 Jul 2014 21:52:56 +0200
Subject: [PATCH 03/10] MIPS: BCM63XX: make fallback sprom optional

Some devices do not provide enough mac addresses to populate wifi in
addition to ethernet.

Use having pci enabled as a rough heuristic which boards should have it
enabled.

Signed-off-by: Jonas Gorski <jogo@openwrt.org>
---
 arch/mips/bcm63xx/boards/board_bcm963xx.c           | 12 ++++++++++++
 arch/mips/bcm63xx/boards/board_common.c             |  5 +++--
 arch/mips/include/asm/mach-bcm63xx/board_bcm963xx.h |  1 +
 3 files changed, 16 insertions(+), 2 deletions(-)

--- a/arch/mips/bcm63xx/boards/board_bcm963xx.c
+++ b/arch/mips/bcm63xx/boards/board_bcm963xx.c
@@ -70,6 +70,7 @@ static struct board_info __initdata boar
 	.has_uart0			= 1,
 	.has_pci			= 1,
 	.has_usbd			= 0,
+	.use_fallback_sprom		= 1,
 
 	.usbd = {
 		.use_fullspeed		= 0,
@@ -219,6 +220,7 @@ static struct board_info __initdata boar
 	.has_uart0			= 1,
 	.has_enet0			= 1,
 	.has_pci			= 1,
+	.use_fallback_sprom		= 1,
 
 	.enet0 = {
 		.has_phy		= 1,
@@ -264,6 +266,7 @@ static struct board_info __initdata boar
 	.has_enet0			= 1,
 	.has_enet1			= 1,
 	.has_pci			= 1,
+	.use_fallback_sprom		= 1,
 
 	.enet0 = {
 		.has_phy		= 1,
@@ -316,6 +319,7 @@ static struct board_info __initdata boar
 	.has_enet0			= 1,
 	.has_enet1			= 1,
 	.has_pci			= 1,
+	.use_fallback_sprom		= 1,
 
 	.enet0 = {
 		.has_phy		= 1,
@@ -370,6 +374,7 @@ static struct board_info __initdata boar
 	.has_enet0			= 1,
 	.has_enet1			= 1,
 	.has_pci			= 1,
+	.use_fallback_sprom		= 1,
 
 	.enet0 = {
 		.has_phy		= 1,
@@ -420,6 +425,7 @@ static struct board_info __initdata boar
 	.has_enet0			= 1,
 	.has_enet1			= 1,
 	.has_pci			= 1,
+	.use_fallback_sprom		= 1,
 
 	.enet0 = {
 		.has_phy		= 1,
@@ -443,6 +449,7 @@ static struct board_info __initdata boar
 	.has_enet0			= 1,
 	.has_enet1			= 1,
 	.has_pci			= 1,
+	.use_fallback_sprom		= 1,
 
 	.enet0 = {
 		.has_phy		= 1,
@@ -460,6 +467,7 @@ static struct board_info __initdata boar
 
 	.has_uart0			= 1,
 	.has_pci			= 1,
+	.use_fallback_sprom		= 1,
 	.has_ohci0			= 1,
 
 	.has_enet0			= 1,
@@ -482,6 +490,7 @@ static struct board_info __initdata boar
 	.has_enet0			= 1,
 	.has_enet1			= 1,
 	.has_pci			= 1,
+	.use_fallback_sprom		= 1,
 
 	.enet0 = {
 		.has_phy		= 1,
@@ -508,6 +517,7 @@ static struct board_info __initdata boar
 	.has_enet0			= 1,
 	.has_enet1			= 1,
 	.has_pci			= 1,
+	.use_fallback_sprom		= 1,
 
 	.enet0 = {
 		.has_phy		= 1,
@@ -559,6 +569,7 @@ static struct board_info __initdata boar
 	.has_enet0			= 1,
 	.has_enet1			= 1,
 	.has_pci			= 1,
+	.use_fallback_sprom		= 1,
 
 	.enet0 = {
 		.has_phy		= 1,
@@ -630,6 +641,7 @@ static struct board_info __initdata boar
 	.has_enet0			= 1,
 	.has_enet1			= 1,
 	.has_pci			= 1,
+	.use_fallback_sprom		= 1,
 
 	.enet0 = {
 		.has_phy		= 1,
--- a/arch/mips/bcm63xx/boards/board_common.c
+++ b/arch/mips/bcm63xx/boards/board_common.c
@@ -183,8 +183,9 @@ int __init board_register_devices(void)
 	 * do this after registering enet devices
 	 */
 
-	if (board_get_mac_address(board.fallback_sprom.mac_addr) ||
-	    bcm63xx_register_fallback_sprom(&board.fallback_sprom))
+	if (board.use_fallback_sprom &&
+	    (board_get_mac_address(board.fallback_sprom.mac_addr) ||
+	     bcm63xx_register_fallback_sprom(&board.fallback_sprom)))
 		pr_err(PFX "failed to register fallback SPROM\n");
 
 	bcm63xx_spi_register();
--- a/arch/mips/include/asm/mach-bcm63xx/board_bcm963xx.h
+++ b/arch/mips/include/asm/mach-bcm63xx/board_bcm963xx.h
@@ -33,6 +33,7 @@ struct board_info {
 	unsigned int	has_usbd:1;
 	unsigned int	has_uart0:1;
 	unsigned int	has_uart1:1;
+	unsigned int	use_fallback_sprom:1;
 
 	/* ethernet config */
 	struct bcm63xx_enet_platform_data enet0;
